[PATCH 2/7] printui: Use LocalFree for memory allocated by LocalAlloc (Coverity)

Fabian Maurer dark.shadow4 at web.de
Sat Apr 23 13:17:24 CDT 2022


Signed-off-by: Fabian Maurer <dark.shadow4 at web.de>
---
 dlls/printui/printui.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/dlls/printui/printui.c b/dlls/printui/printui.c
index 8f65ed27e87..13669f05aab 100644
--- a/dlls/printui/printui.c
+++ b/dlls/printui/printui.c
@@ -227,7 +227,7 @@ void WINAPI PrintUIEntryW(HWND hWnd, HINSTANCE hInst, LPCWSTR pCommand, DWORD nC
     cx.nCmdShow = nCmdShow;

     if ((pCommand) && (pCommand[0])) {
         /* result is allocated with GlobalAlloc() */
         cx.argv = CommandLineToArgvW(pCommand, &cx.argc);
         TRACE("got %d args at %p\n", cx.argc, cx.argv);

@@ -253,6 +253,6 @@ void WINAPI PrintUIEntryW(HWND hWnd, HINSTANCE hInst, LPCWSTR pCommand, DWORD nC
         FIXME("dialog: Printer / The operation was not successful\n");
     }

-    GlobalFree(cx.argv);
+    LocalFree(cx.argv);

 }
@@ -227,7 +227,7 @@ void WINAPI PrintUIEntryW(HWND hWnd, HINSTANCE hInst, LPCWSTR pCommand, DWORD nC

     if ((pCommand) && (pCommand[0])) {
-        /* result is allocated with GlobalAlloc() */
+        /* result is allocated with LocalAlloc() */
         cx.argv = CommandLineToArgvW(pCommand, &cx.argc);
         TRACE("got %d args at %p\n", cx.argc, cx.argv);
--
2.36.0




More information about the wine-devel mailing list